aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/release_abstract.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/release_abstract.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_abstract.py19
1 files changed, 10 insertions, 9 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/release_abstract.py b/python_openapi_client/fatcat_openapi_client/models/release_abstract.py
index 7ba8348e..c6c7aab7 100644
--- a/python_openapi_client/fatcat_openapi_client/models/release_abstract.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_abstract.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -18,19 +18,20 @@ import six
class ReleaseAbstract(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'sha1': 'str',
'content': 'str',
'mimetype': 'str',
@@ -45,7 +46,7 @@ class ReleaseAbstract(object):
}
def __init__(self, sha1=None, content=None, mimetype=None, lang=None): # noqa: E501
- """ReleaseAbstract - a model defined in Swagger""" # noqa: E501
+ """ReleaseAbstract - a model defined in OpenAPI""" # noqa: E501
self._sha1 = None
self._content = None
@@ -86,8 +87,8 @@ class ReleaseAbstract(object):
raise ValueError("Invalid value for `sha1`, length must be less than or equal to `40`") # noqa: E501
if sha1 is not None and len(sha1) < 40:
raise ValueError("Invalid value for `sha1`, length must be greater than or equal to `40`") # noqa: E501
- if sha1 is not None and not re.search('[a-f0-9]{40}', sha1): # noqa: E501
- raise ValueError("Invalid value for `sha1`, must be a follow pattern or equal to `/[a-f0-9]{40}/`") # noqa: E501
+ if sha1 is not None and not re.search(r'[a-f0-9]{40}', sha1): # noqa: E501
+ raise ValueError(r"Invalid value for `sha1`, must be a follow pattern or equal to `/[a-f0-9]{40}/`") # noqa: E501
self._sha1 = sha1
@@ -164,7 +165,7 @@ class ReleaseAbstract(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -18,19 +18,20 @@ import six
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name